@@ -1,8 +1,13 @@
 import os
+import unittest
 
 import six
 
-from traits.testing.unittest_tools import unittest
+try:
+    import traitsui
+    HAS_TRAITSUI = True
+except ImportError:
+    HAS_TRAITSUI = False
 
 from traits.api import File, HasTraits, TraitError
 
@@ -49,3 +54,16 @@ class FileTestCase(unittest.TestCase):
         example_model = FastExampleModel(file_name=__file__)
         example_model.path = "."
         example_model.path = u"."
+
+
+class TestCreateEditor(unittest.TestCase):
+
+    @unittest.skipUnless(HAS_TRAITSUI, "This test needs traitsui")
+    def test_exists_controls_editor_dialog_style(self):
+        x = File(exists=True)
+        editor = x.create_editor()
+        self.assertEqual(editor.dialog_style, "open")
+
+        x = File(exists=False)
+        editor = x.create_editor()
+        self.assertEqual(editor.dialog_style, "save")
